/**
 * Transform one of:
 *
 * ```ts
 * CID
 * String
 * { cid: CID recursive, metadata }
 * { path: String recursive, metadata }
 * Iterable<CID>
 * Iterable<String>
 * Iterable<{ cid: CID recursive, metadata }>
 * Iterable<{ path: String recursive, metadata }>
 * AsyncIterable<CID>
 * AsyncIterable<String>
 * AsyncIterable<{ cid: CID recursive, metadata }>
 * AsyncIterable<{ path: String recursive, metadata }>
 * ```
 * Into:
 *
 * ```ts
 * AsyncIterable<{ path: CID|String, recursive:boolean, metadata }>
 * ```
 *
 * @param {Source} input
 * @returns {AsyncIterable<Pin>}
 */
export function normaliseInput(input: Source): AsyncIterable<Pin>;
export type Pinnable = {
    path?: string | String | CID<any, number, number, import("multiformats/cid").Version> | undefined;
    cid?: CID<any, number, number, import("multiformats/cid").Version> | undefined;
    recursive?: boolean | undefined;
    metadata?: any;
};
export type ToPin = CID | string | InstanceType<typeof window.String> | Pinnable;
export type Source = ToPin | Iterable<ToPin> | AsyncIterable<ToPin>;
export type Pin = {
    path: string | CID;
    recursive: boolean;
    metadata?: any;
};
import { CID } from "multiformats/cid";
//# sourceMappingURL=normalise-input.d.ts.map